==> linkie-0.0.2.tgz: package/lib/linkie.js <==
(function webpackUniversalModuleDefinition(root, factory) {
	if(typeof exports === 'object' && typeof module === 'object')
		module.exports = factory();
	else if(typeof define === 'function' && define.amd)
		define("linkie", [], factory);
	else if(typeof exports === 'object')
		exports["linkie"] = factory();
	else
		root["linkie"] = factory();
})(this, function() {
return /******/ (function(modules) { // webpackBootstrap
/******/ 	// The module cache
/******/ 	var installedModules = {};
/******/
/******/ 	// The require function
/******/ 	function __webpack_require__(moduleId) {
/******/
/******/ 		// Check if module is in cache
/******/ 		if(installedModules[moduleId]) {
/******/ 			return installedModules[moduleId].exports;
/******/ 		}
/******/ 		// Create a new module (and put it into the cache)
/******/ 		var module = installedModules[moduleId] = {
/******/ 			i: moduleId,
/******/ 			l: false,
/******/ 			exports: {}
/******/ 		};
/******/
/******/ 		// Execute the module function
/******/ 		modules[moduleId].call(module.exports, module, module.exports, __webpack_require__);
/******/
/******/ 		// Flag the module as loaded
/******/ 		module.l = true;
/******/
/******/ 		// Return the exports of the module
/******/ 		return module.exports;
/******/ 	}
/******/
/******/
/******/ 	// expose the modules object (__webpack_modules__)
/******/ 	__webpack_require__.m = modules;
/******/
/******/ 	// expose the module cache
/******/ 	__webpack_require__.c = installedModules;
/******/
/******/ 	// define getter function for harmony exports
/******/ 	__webpack_require__.d = function(exports, name, getter) {
/******/ 		if(!__webpack_require__.o(exports, name)) {
/******/ 			Object.defineProperty(exports, name, {
/******/ 				configurable: false,
/******/ 				enumerable: true,
/******/ 				get: getter
/******/ 			});
/******/ 		}
/******/ 	};
/******/
/******/ 	// getDefaultExport function for compatibility with non-harmony modules
/******/ 	__webpack_require__.n = function(module) {
/******/ 		var getter = module && module.__esModule ?
/******/ 			function getDefault() { return module['default']; } :
/******/ 			function getModuleExports() { return module; };
/******/ 		__webpack_require__.d(getter, 'a', getter);
/******/ 		return getter;
/******/ 	};
/******/
/******/ 	// Object.prototype.hasOwnProperty.call
/******/ 	__webpack_require__.o = function(object, property) { return Object.prototype.hasOwnProperty.call(object, property); };
/******/
/******/ 	// __webpack_public_path__
/******/ 	__webpack_require__.p = "";
/******/
/******/ 	// Load entry module and return exports
/******/ 	return __webpack_require__(__webpack_require__.s = 0);
/******/ })
/************************************************************************/
/******/ ([
/* 0 */
/***/ (function(module, exports, __webpack_require__) {

"use strict";


var fetch = __webpack_require__(1);

module.exports = {
    fetch: fetch
};

/***/ }),
/* 1 */
/***/ (function(module, exports, __webpack_require__) {

"use strict";


var trim = __webpack_require__(2);
var cheerio = __webpack_require__(3);
var requests = __webpack_require__(4);

function _getTitle(cheerioObject) {
    var title = cheerioObject('head').text();
    return title ? trim(title) : '';
}

function _getDescription(cheerioObject) {
    var description = cheerioObject('meta[name=\'description\']').attr('content');
    return description ? trim(description) : '';
}

function _getFirstParagraph(cheerioObject) {
    var minLength = 128;
    var description = '';
    var allP = cheerioObject('p');
    for (var i = 0; i < allP.length; i += 1) {
        description += cheerioObject(allP[i]).text();
        if (description.length > minLength) {
            return description;
        }
    }
    return description;
}

function _getFirstImage(cheerioObject) {
    var images = cheerioObject('img');
    if (images && images[0]) {
        var imageUrl = cheerioObject(images[0]).attr('src');
        return imageUrl ? trim(imageUrl) : '';
    }
    return '';
}

function _getKeywords(cheerioObject) {
    var keywordsContent = cheerioObject('meta[name=\'keywords\']').attr('content');
    if (keywordsContent) {
        return keywordsContent.split(',').map(function (e) {
            return trim(e);
        }).filter(function (e) {
            return e !== '';
        });
    }
    return [];
}

function _getOgTitle(cheerioObject) {
    var title = cheerioObject('meta[property=\'og:title\']').attr('content');
    return title ? trim(title) : '';
}

function _getOgDescription(cheerioObject) {
    var description = cheerioObject('meta[property=\'og:description\']').attr('content');
    return description ? trim(description) : '';
}

function _getOgType(cheerioObject) {
    var type = cheerioObject('meta[property=\'og:type\']').attr('content');
    return type ? trim(type) : '';
}

function _getOgImage(cheerioObject) {
    var imageUrl = cheerioObject('meta[property=\'og:image\']').attr('content');
    return imageUrl ? trim(imageUrl) : '';
}

module.exports = function (url, callback) {
    requests.get(url).redirects(2).timeout({
        response: 2000,
        deadline: 3000
    }).ok(function (res) {
        return res.status < 500;
    }).end(function (err, res) {
        if (err) {
            return callback({
                message: 'Unable to fetch meta information for ' + url,
                code: err.code,
                errno: err.errno,
                status: err.status
            }, null);
        }
        var cheerioObject = cheerio.load(res.text);
        return callback(null, {
            url: url,
            status: res.status,
            host: res.request.host,
            title: _getOgTitle(cheerioObject) || _getTitle(cheerioObject),
            description: _getOgDescription(cheerioObject) || _getDescription(cheerioObject) || _getFirstParagraph(cheerioObject),
            type: _getOgType(cheerioObject),
            keywords: _getKeywords(cheerioObject),
            image: _getOgImage(cheerioObject) || _getFirstImage(cheerioObject)
        });
    });
};

/***/ }),
/* 2 */
/***/ (function(module, exports) {

module.exports = require("trim");

/***/ }),
/* 3 */
/***/ (function(module, exports) {

module.exports = require("cheerio");

/***/ }),
/* 4 */
/***/ (function(module, exports) {

module.exports = require("superagent");

/***/ })
/******/ ]);
});

==> linkie-0.0.4.tgz: package/lib/linkie.js <==
(function webpackUniversalModuleDefinition(root, factory) {
	if(typeof exports === 'object' && typeof module === 'object')
		module.exports = factory();
	else if(typeof define === 'function' && define.amd)
		define("linkie", [], factory);
	else if(typeof exports === 'object')
		exports["linkie"] = factory();
	else
		root["linkie"] = factory();
})(this, function() {
return /******/ (function(modules) { // webpackBootstrap
/******/ 	// The module cache
/******/ 	var installedModules = {};
/******/
/******/ 	// The require function
/******/ 	function __webpack_require__(moduleId) {
/******/
/******/ 		// Check if module is in cache
/******/ 		if(installedModules[moduleId]) {
/******/ 			return installedModules[moduleId].exports;
/******/ 		}
/******/ 		// Create a new module (and put it into the cache)
/******/ 		var module = installedModules[moduleId] = {
/******/ 			i: moduleId,
/******/ 			l: false,
/******/ 			exports: {}
/******/ 		};
/******/
/******/ 		// Execute the module function
/******/ 		modules[moduleId].call(module.exports, module, module.exports, __webpack_require__);
/******/
/******/ 		// Flag the module as loaded
/******/ 		module.l = true;
/******/
/******/ 		// Return the exports of the module
/******/ 		return module.exports;
/******/ 	}
/******/
/******/
/******/ 	// expose the modules object (__webpack_modules__)
/******/ 	__webpack_require__.m = modules;
/******/
/******/ 	// expose the module cache
/******/ 	__webpack_require__.c = installedModules;
/******/
/******/ 	// define getter function for harmony exports
/******/ 	__webpack_require__.d = function(exports, name, getter) {
/******/ 		if(!__webpack_require__.o(exports, name)) {
/******/ 			Object.defineProperty(exports, name, {
/******/ 				configurable: false,
/******/ 				enumerable: true,
/******/ 				get: getter
/******/ 			});
/******/ 		}
/******/ 	};
/******/
/******/ 	// getDefaultExport function for compatibility with non-harmony modules
/******/ 	__webpack_require__.n = function(module) {
/******/ 		var getter = module && module.__esModule ?
/******/ 			function getDefault() { return module['default']; } :
/******/ 			function getModuleExports() { return module; };
/******/ 		__webpack_require__.d(getter, 'a', getter);
/******/ 		return getter;
/******/ 	};
/******/
/******/ 	// Object.prototype.hasOwnProperty.call
/******/ 	__webpack_require__.o = function(object, property) { return Object.prototype.hasOwnProperty.call(object, property); };
/******/
/******/ 	// __webpack_public_path__
/******/ 	__webpack_require__.p = "";
/******/
/******/ 	// Load entry module and return exports
/******/ 	return __webpack_require__(__webpack_require__.s = 0);
/******/ })
/************************************************************************/
/******/ ([
/* 0 */
/***/ (function(module, exports, __webpack_require__) {

"use strict";


var fetch = __webpack_require__(1);

module.exports = {
    fetch: fetch
};

/***/ }),
/* 1 */
/***/ (function(module, exports, __webpack_require__) {

"use strict";


var trim = __webpack_require__(2);
var cheerio = __webpack_require__(3);
var requests = __webpack_require__(4);
var specifics = __webpack_require__(5);

function _getTitle(cheerioObject) {
    var title = cheerioObject('head').text();
    return title ? trim(title) : '';
}

function _getDescription(cheerioObject) {
    var description = cheerioObject('meta[name=\'description\']').attr('content');
    return description ? trim(description) : '';
}

function _getFirstParagraph(cheerioObject) {
    var minLength = 128;
    var description = '';
    var allP = cheerioObject('p');
    for (var i = 0; i < allP.length; i += 1) {
        description += cheerioObject(allP[i]).text();
        if (description.length > minLength) {
            return description;
        }
    }
    return description;
}

function _getFirstImage(cheerioObject) {
    var images = cheerioObject('img');
    if (images && images[0]) {
        var imageUrl = cheerioObject(images[0]).attr('src');
        return imageUrl ? trim(imageUrl) : '';
    }
    return '';
}

function _getKeywords(cheerioObject) {
    var keywordsContent = cheerioObject('meta[name=\'keywords\']').attr('content');
    if (keywordsContent) {
        return keywordsContent.split(',').map(function (e) {
            return trim(e);
        }).filter(function (e) {
            return e !== '';
        });
    }
    return [];
}

function _getOgTitle(cheerioObject) {
    var title = cheerioObject('meta[property=\'og:title\']').attr('content');
    return title ? trim(title) : '';
}

function _getOgDescription(cheerioObject) {
    var description = cheerioObject('meta[property=\'og:description\']').attr('content');
    return description ? trim(description) : '';
}

function _getOgType(cheerioObject) {
    var type = cheerioObject('meta[property=\'og:type\']').attr('content');
    return type ? trim(type) : '';
}

function _getOgImage(cheerioObject) {
    var imageUrl = cheerioObject('meta[property=\'og:image\']').attr('content');
    return imageUrl ? trim(imageUrl) : '';
}

module.exports = function (url, callback) {
    requests.get(url).redirects(2).timeout({
        response: 3000,
        deadline: 10000
    }).ok(function (res) {
        return res.status < 500;
    }).end(function (err, res) {
        if (err) {
            return callback({
                message: 'Unable to fetch meta information for ' + url,
                code: err.code,
                errno: err.errno,
                status: err.status
            }, null);
        }
        var cheerioObject = cheerio.load(res.text);

        var metadata = {
            url: url,
            status: res.status,
            host: res.request.host,
            title: _getOgTitle(cheerioObject) || _getTitle(cheerioObject),
            description: _getOgDescription(cheerioObject) || _getDescription(cheerioObject) || _getFirstParagraph(cheerioObject),
            type: _getOgType(cheerioObject),
            keywords: _getKeywords(cheerioObject),
            image: _getOgImage(cheerioObject) || _getFirstImage(cheerioObject)
        };

        var site = specifics.getSite(res.request.host);
        if (site) {
            metadata.site = site;
        }
        return callback(null, metadata);
    });
};

/***/ }),
/* 2 */
/***/ (function(module, exports) {

module.exports = require("trim");

/***/ }),
/* 3 */
/***/ (function(module, exports) {

module.exports = require("cheerio");

/***/ }),
/* 4 */
/***/ (function(module, exports) {

module.exports = require("superagent");

/***/ }),
/* 5 */
/***/ (function(module, exports, __webpack_require__) {

"use strict";


var hostSiteMap = {
    'www.youtube.com': 'youtube',
    'github.com': 'github'
};

var hostSiteMapKeys = Object.keys(hostSiteMap);

module.exports = {
    getSite: function getSite(host) {
        for (var i = 0; i < hostSiteMapKeys.length; i += 1) {
            var key = hostSiteMapKeys[i];
            var value = hostSiteMapKeys[key];
            if (host.indexOf(key) !== -1) {
                return value;
            }
        }
        return null;
    }
};

/***/ })
/******/ ]);
});
